@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* acp_board [Finnish]
+* acp_board [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
     'SYSTEM_TIMEZONE'               => 'Vierailijan aikavyöhyke',
     'SYSTEM_TIMEZONE_EXPLAIN'       => 'Tämä aikavyöhyke on käytössä heille, jotka eivät ole kirjautuneet sisään. Sisäänkirjautuneet käyttäjät voivat muokata aikavyöhykettään omista asetuksistansa.',
 	'WARNINGS_EXPIRE'				=> 'Varoitusten kesto',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Kuinka monta päivää annettu varoitus pysyy voimassa ennen kuin se poistetaan käyttäjän tiedoista',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Kuinka monta päivää annettu varoitus pysyy voimassa ennen kuin se poistetaan käyttäjän tiedoista. Aseta tähän 0 pitääksesi varoitukset pysyvinä',
 ));
 
 // Board Features
@@ -177,7 +177,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Viestissä olevien linkkien maksimi määrä.',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Aseta nolla poistaaksesi rajoituksen käytöstä.',
 	'MIN_CHAR_LIMIT'				=> 'Minimimäärä merkkejä viesteissä',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Minimimäärä merkkejä viesteissä/yksityisviesteissä.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Minimimäärä merkkejä viesteissä/yksityisviesteissä. Pienin arvo tälle asetukselle on 1',
 	'POSTING'						=> 'Viestien lähetys',
 	'POSTS_PER_PAGE'				=> 'Viestiä per sivu',
 	'QUOTE_DEPTH_LIMIT'				=> 'Viestissä olevien lainauksien maksimi määrä',
@@ -491,10 +491,10 @@ $lang = array_merge($lang, array(
 	'REFERER_VALID_EXPLAIN'			=> 'Mikäli käytössä, POST pyynnön viittaaja tarkistetaan isännän ja skriptin polun mukaan. Tämä saattaa aiheuttaa ongelmia, jos keskustelufoorumi käyttää useaa osoitetta tai ulkopuolisia kirjautumisia.',
 	'PASSWORD_TYPE'					=> 'Salasanan monimutkaisuus',
 	'PASSWORD_TYPE_EXPLAIN'			=> 'Määrittelee kuinka monimutkaisen salasanan on oltava sitä asettaessa tai muutettaessa. seuraavat asetukset kuuluvat edellisiin asetuksiin.',
-	'PASS_TYPE_ALPHA'				=> 'Täytyy sisältää alphanumeerisia merkkejä',
+	'PASS_TYPE_ALPHA'				=> 'Täytyy sisältää ISOJA ja pieniä kirjaimia, sekä numeroita',
 	'PASS_TYPE_ANY'					=> 'Ei vaatimuksia',
-	'PASS_TYPE_CASE'				=> 'Täytyy sekoittaa isoja ja pieniä kirjaimia',
-	'PASS_TYPE_SYMBOL'				=> 'Täytyy sisältää symbooleita',
+	'PASS_TYPE_CASE'				=> 'Täytyy sisältää ISOJA ja pieniä kirjaimia',
+	'PASS_TYPE_SYMBOL'				=> 'Täytyy sisältää ISOJA ja pieniä kirjaimia, sekä numeroita ja symboleita',
 	'TPL_ALLOW_PHP'					=> 'Salli PHP:n käyttö mallineissa',
 	'TPL_ALLOW_PHP_EXPLAIN'			=> 'Mikäli tämä vaihtoehto on käytössä, <code>PHP</code> ja <code>INCLUDEPHP</code> käskyt tunnistetaan mallineissa ja suoritetaan.',
 ));
