@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* acp_common [Finnish]
+* acp_common [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -325,6 +325,15 @@ $lang = array_merge($lang, array(
 
 	'DATABASE_SERVER_INFO'	=> 'Tietokantapalvelin',
 	'DATABASE_SIZE'			=> 'Tietokannan koko',
+	// Enviroment configuration checks, mbstring related
+'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Function overload ei ole asetettu oikein',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> arvon tulee olla asetettu joko 0 tai 4. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Läpinäkyvä merkistönkoodaus ei ole asetettu oikein',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> arvon tulee olla 0. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input merkistön konversio ei ole asetettu oikein',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> arvon tulee olla <samp>pass</samp>. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output merkistön konversio ei ole asetettu oikein',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> arvon tulee olla <samp>pass</samp>. Voit tarkistaa nykyisen arvon <samp>PHP informaatio</samp> -sivulta.',
 
 	'FILES_PER_DAY'		=> 'Liitetiedostoja päivässä',
 	'FORUM_STATS'		=> 'Keskustelufoorumin tilastot',
