@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* acp_styles [Finnish]
+* acp_styles [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -129,7 +129,7 @@ $lang = array_merge($lang, array(
 	'IMAGESET_DETAILS_UPDATED'	=> 'Kuvapaketin tiedot ovat päivitetty',
 	'IMAGESET_ERR_ARCHIVE'		=> 'Ole hyvä ja valitse arkistointitapa',
 	'IMAGESET_ERR_COPY_LONG'	=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
-	'IMAGESET_ERR_NAME_CHARS'	=> 'Kuvapaketin nimessa voi olla vain alphanumeerisia merkkejä, -, +, _ ja välilyöntejä',
+	'IMAGESET_ERR_NAME_CHARS'	=> 'Kuvapaketin nimessa voi olla vain kirjaimia, numeroita, -, +, _ ja välilyöntejä',
 	'IMAGESET_ERR_NAME_EXIST'	=> 'Tämän niminen kuvapaketti on jo olemassa',
 	'IMAGESET_ERR_NAME_LONG'	=> 'Kuvapaketin nimi ei voi olla 30 merkkiä pidempi',
 	'IMAGESET_ERR_NOT_IMAGESET'	=> 'Määrittämässäsi arkistossa ei ole kelvollista kuvapakettia.',
@@ -349,7 +349,7 @@ $lang = array_merge($lang, array(
 	'STYLE_ERR_ARCHIVE'			=> 'Ole hyvä ja valitse arkistointi metodi',
 	'STYLE_ERR_COPY_LONG'		=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
 	'STYLE_ERR_MORE_ELEMENTS'	=> 'Sinun pitää valita ainakin yksi tyylin elementti.',
-	'STYLE_ERR_NAME_CHARS'		=> 'Tyylin nimi voi koostua vain alphanumeerisista merkeistä, -, +, _ ja välilyönnistä',
+	'STYLE_ERR_NAME_CHARS'		=> 'Tyylin nimi voi koostua vain kirjaimista, numeroista, -, +, _ ja välilyönnistä',
 	'STYLE_ERR_NAME_EXIST'		=> 'Tämän niminen tyyli on jo olemassa',
 	'STYLE_ERR_NAME_LONG'		=> 'Tyylin nimi ei voi olla yli 30 merkkiä pitkä',
 	'STYLE_ERR_NO_IDS'			=> 'Sinun täytyy valita malline, teema ja kuvapaketti tälle tyylille',
@@ -379,7 +379,7 @@ $lang = array_merge($lang, array(
 	'TEMPLATE_ERR_ARCHIVE'		=> 'Ole hyvä ja valitse arkistointi metodi',
 	'TEMPLATE_ERR_CACHE_READ'	=> 'Välimuistin käyttämää hakemistoa ei voitu avata.',
 	'TEMPLATE_ERR_COPY_LONG'	=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
-	'TEMPLATE_ERR_NAME_CHARS'	=> 'mallineen nimi voi koostua vain alphanumeerisista merkeistä, -, +, _ ja välilyönneistä',
+	'TEMPLATE_ERR_NAME_CHARS'	=> 'mallineen nimi voi koostua vain kirjaimista, numeroista, -, +, _ ja välilyönneistä',
 	'TEMPLATE_ERR_NAME_EXIST'	=> 'Tämän niminen mallinepaketti on jo olemassa',
 	'TEMPLATE_ERR_NAME_LONG'	=> 'mallineen nimi ei voi olla 30 merkkiää pidempi',
 	'TEMPLATE_ERR_NOT_TEMPLATE'	=> 'Määrittämässäsi arkistossa ei ole kelvollista mallinepakettia.',
@@ -406,9 +406,9 @@ $lang = array_merge($lang, array(
 	'THEME_EDITOR'				=> 'Raaka CSS teema editori',
 	'THEME_EDITOR_HEIGHT'		=> 'Teema editorin korkeus',
 	'THEME_ERR_ARCHIVE'			=> 'Ole hyvä ja valitse arkistointi metodi',
-	'THEME_ERR_CLASS_CHARS'		=> 'Vain alphanumeeriset merkit ja ., :, - ja # on sallittu luokkien nimissä.',
+	'THEME_ERR_CLASS_CHARS'		=> 'Vain kirjaimet, numerot ja ., :, - ja # on sallittu luokkien nimissä.',
 	'THEME_ERR_COPY_LONG'		=> 'Tekijänoikeustiedot eivät voi olla 60 merkkiä pidemmät',
-	'THEME_ERR_NAME_CHARS'		=> 'Teeman nimessä voi olla vain alphanumeerisia merkkejä, -, +, _ ja välilyöntejä',
+	'THEME_ERR_NAME_CHARS'		=> 'Teeman nimessä voi olla vain kirjaimia, numeroita, -, +, _ ja välilyöntejä',
 	'THEME_ERR_NAME_EXIST'		=> 'Tämän niminen teema on jo olemassa',
 	'THEME_ERR_NAME_LONG'		=> 'Teeman nimi ei voi olla 30 merkkiä pidempi',
 	'THEME_ERR_NOT_THEME'		=> 'Määrittämässäsi arkistossa ei ole kelvollista teemaa.',
