@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* common [Finnish]
+* common [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Sinun täytyy antaa aihe kirjoittaessasi uutta viestiä.',
 	'ENABLED'							=> 'Päällä',
 	'ENCLOSURE'							=> 'Liite',
+	'ENTER_USERNAME'					=> 'Anna käyttäjätunnus',
 	'ERR_CHANGING_DIRECTORY'			=> 'Hakemiston vaihtaminen ei onnistunut',
 	'ERR_CONNECTING_SERVER'				=> 'Yhteysvirhe palvelimeen',
 	'ERR_JAB_AUTH'						=> 'Jabber-palvelimelle tunnistautuminen epäonnistui.',
@@ -199,7 +200,8 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES'			=> 'Alueen säännöt',
 	'FORUM_RULES_LINK'		=> 'Paina linkkiä nähdäksesi säännöt',
 	'FROM'					=> 'Lähettäjä',
-	'FSOCK_DISABLED'		=> 'Operaatiota ei voitu suorittaa loppuun koska fsock-funktiot ovat poissa käytöstä tai pyydettyä palvelinta ei löytynyt.',
+	'FSOCK_DISABLED'		=> 'Operaatiota ei voitu suorittaa loppuun koska <var>fsockopen</var> -funktiot ovat poissa käytöstä tai pyydettyä palvelinta ei löytynyt.',
+	'FSOCK_TIMEOUT'			=> 'Verkossa tapahtui aikakatkaisu luettaessa.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-palvelin',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-palvelin, jossa saa yhteyden sivustoosi',
@@ -649,6 +651,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> lukemattomia viestejä',
     'UNREAD_POST'           => 'Lukematon viesti',
     'UNREAD_POSTS'          => 'Lukemattomat viestit',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Haluatko lopettaa tämän alueen seurannan?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Haluatko varmasti lopettaa “%s” seurannan?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Haluatko lopettaa tämän viestiketjun seurannan?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Haluatko varmasti lopettaa “%s” seurannan?',
 	'UNWATCHED_FORUMS'		=> 'Et enää seuraa valitsemaasi aluetta.',
 	'UNWATCHED_TOPICS'		=> 'Et enää seuraa valitsemaasi viestiketjua.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Et enää seuraa valitsemiasi merkintöjä.',
@@ -696,6 +702,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Varoitukset',
 	'WARN_USER'			=> 'Anna varoitus',
+	'WATCH_FORUM_CONFIRM'	=> 'Haluatko varmasti seurata tätä aluetta?',
+	'WATCH_FORUM_DETAILED'	=> 'Haluatko varmasti seurata aluetta“%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Haluatko varmasti seurata tätä viestiketjua?',
+	'WATCH_TOPIC_DETAILED'	=> 'Haluatko varmasti seurata viestiketjua “%s”?',
 	'WELCOME_SUBJECT'	=> 'Tervetuloa %s keskustelufoorumille',
 	'WEBSITE'			=> 'Kotisivu',
 	'WHOIS'				=> 'Whois',
