@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* ucp [Finnish]
+* ucp [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -138,6 +138,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Nykyinen kuva',
 	'CURRENT_PASSWORD'			=> 'Nykyinen salasana',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Vahvista sähköpostiosoitteen ja käyttäjätunnuksen vaihto antamalla salasanasi.',
+	'CUR_PASSWORD_EMPTY'		=> 'Et antanut nykyistä salasanaasi.',
 	'CUR_PASSWORD_ERROR'		=> 'Antamasi salasana on virheellinen.',
 	'CUSTOM_DATEFORMAT'			=> 'Mukautettu...',
 
@@ -192,8 +193,8 @@ $lang = array_merge($lang, array(
 	'FIELD_TOO_SMALL'					=> '"%1$s" arvo on liian matala. Minimi arvo on %2$d .',
 	'FIELD_TOO_LARGE'					=> '"%1$s" arvo on liian suuri. Maksimi arvo on %2$d .',
 	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain numerot ovat sallittuja.',
-	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain alphanumeeriset merkit ovat sallittuja.',
-	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain alphanumeeriset, välilyönnit tai -+_[] merkit ovat sallittuja.',
+	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain kirjoitusmerkit ovat sallittuja.',
+	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Kentässä “%s” on epäkelpoja merkkejä. Vain kirjaimet, numerot, välilyönnit tai -+_[] merkit ovat sallittuja.',
 	'FIELD_INVALID_DATE'				=> 'Kentässä “%s” on epäkelpo päivämäärä.',
     'FIELD_INVALID_VALUE'            	=> 'Kentässä “%s” on epäkelpo arvo.',
 
@@ -267,10 +268,12 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'					=> 'Viestien siirrossa tapahtui virhe, vain %1d / %2d viestistä on siirretty.',
 	'MOVE_TO_FOLDER'				=> 'Siirrä kansioon',
 	'MOVE_UP'						=> 'Siirrä ylöspäin',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Et varmistanut sähköpostiosoitettasi.',
 
 	'NEW_EMAIL_ERROR'				=> 'Antamasi sähköpostiosoitteet eivät ole samanlaisia.',
 	'NEW_FOLDER_NAME'				=> 'Uuden kansion nimi',
 	'NEW_PASSWORD'					=> 'Salasana',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Et varmistanut salasanaasi.',
 	'NEW_PASSWORD_ERROR'			=> 'Antamasi salasanat eivät ole samanlaisia.',
 	'NOTIFY_METHOD'					=> 'Ilmoitustapa',
 	'NOTIFY_METHOD_BOTH'			=> 'kummatkin',
@@ -330,10 +333,10 @@ $lang = array_merge($lang, array(
     'NO_WATCHED_SELECTED'       => 'Et valinnut yhtään seurannassa olevaa aluetta tai viestiä.',
 	'NO_WATCHED_TOPICS'			=> 'Et seuraa yhtäkään viestiketjua.',
 
-	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä tulee olla alphanumeerisia merkkejä',
+	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä. Siinä tulee olla ISOJA ja pieniä kirjaimia, sekä numeroita',
 	'PASS_TYPE_ANY_EXPLAIN'		=> 'Pituuden täytyy olla %1$d ja %2$d merkin väliltä.',
-	'PASS_TYPE_CASE_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä tulee sekoittaa isoja ja pieniä kirjaimia',
-	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä täytyy olla symboleita',
+	'PASS_TYPE_CASE_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä. Siinä tulee sekoittaa ISOJA ja pieniä kirjaimia',
+	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Salasanan pituus täytyy olla %1$d ja %2$d merkin väliltä. Siinä tulee olla ISOJA ja pieniä kirjaimia, sekä numeroita ja symboleita',
 	'PASSWORD'					=> 'Salasana',
 	'PASSWORD_ACTIVATED'		=> 'uusi salasanasi on aktivoitu',
 	'PASSWORD_UPDATED'			=> 'salasanasi on lähetetty tiedoissasi olevaan sähköpostiosoitteeseen.',
@@ -468,8 +471,8 @@ $lang = array_merge($lang, array(
 	'UPLOAD_AVATAR_FILE'			=> 'Siirrä omalta koneeltasi',
 	'UPLOAD_AVATAR_URL'				=> 'Kopioi osoitteesta',
 	'UPLOAD_AVATAR_URL_EXPLAIN'		=> 'Anna avatar-kuvan osoite. Kuva kopioidaan tämän sivuston palvelimelle.',
-	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Käyttäjätunnuksessa täytyy olla vähintään %1$d merkkiä ja maksimissaan %2$d merkkiä. Voit käyttää vain alphanumeerisia merkkejä',
-	'USERNAME_ALPHA_SPACERS_EXPLAIN'=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä tulee olla alphanumeerisia merkkejä,välilyöntejä tai -+_[] merkkejä.',
+	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Käyttäjätunnuksessa täytyy olla vähintään %1$d merkkiä ja maksimissaan %2$d merkkiä. Voit käyttää vain kirjaimia ja numeroita',
+	'USERNAME_ALPHA_SPACERS_EXPLAIN'=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja siinä tulee olla kirjaimia, numeroita ,välilyöntejä tai -+_[] merkkejä.',
 	'USERNAME_ASCII_EXPLAIN'		=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää ainoastaan ASCII merkkejä, eli ei symboleja',
 	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää ainoastaan kirjaimia ja numeroita',
 	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'=> 'Käyttäjätunnuksen pituus täytyy olla %1$d ja %2$d merkin väliltä ja käyttää kirjaimia, numeroita, välilyöntiä tai -+_[] merkkejä.',
